@@ -2,7 +2,7 @@
 #' @aliases cfbd_games
 #' @title
 #' **CFBD Games Endpoint Overview**
-#' @description Get results, statistics and information for games\cr
+#' @description Get results, statistics and information for games
 #' \describe{
 #'   \item{`cfbd_game_box_advanced()`:}{ Get game advanced box score information.}
 #'   \item{`cfbd_game_player_stats()`:}{ Get results information from games.}
@@ -72,12 +72,12 @@ NULL
 #' @param team (*String* optional): D-I Team
 #' @param home_team (*String* optional): Home D-I Team
 #' @param away_team (*String* optional): Away D-I Team
-#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference\cr
-#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC\cr
-#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC\cr
+#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
+#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
+#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
 #' @param game_id (*Integer* optional): Game ID filter for querying a single game
 #' @param quarter_scores (*Logical* default FALSE): This is a parameter to return the
-#' list columns that give the score at each quarter: `home_line_scores` and `away_line_scores`.\cr
+#' list columns that give the score at each quarter: `home_line_scores` and `away_line_scores`.
 #' I have defaulted the parameter to false so that you will not have to go to the trouble of dropping it.
 #'
 #' @return [cfbd_game_info()] - A data frame with 22 variables:
@@ -122,12 +122,7 @@ NULL
 #' @export
 #' @examples
 #' \donttest{
-#'   cfbd_game_info(2018, week = 1)
-#'
-#'   cfbd_game_info(2018, week = 7, conference = "Ind")
-#'
-#'   # 7 OTs LSU @ TAMU
-#'   cfbd_game_info(2018, week = 13, team = "Texas A&M", quarter_scores = TRUE)
+#'   try(cfbd_game_info(2018, week = 7, conference = "Ind"))
 #' }
 
 cfbd_game_info <- function(year,
@@ -203,18 +198,19 @@ cfbd_game_info <- function(year,
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
-
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
@@ -231,12 +227,13 @@ cfbd_game_info <- function(year,
 
         colnames(df) <- gsub("_line_scores", "_scores", colnames(df))
         df <- df %>%
-          dplyr::rename(game_id = .data$id) %>%
-          as.data.frame()
+          dplyr::rename(game_id = .data$id)
       }
+      df <- df %>%
+        make_cfbfastR_data("Game information from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
-        message(glue::glue("{Sys.time()}: Invalid arguments or no game info data available!"))
+      message(glue::glue("{Sys.time()}: Invalid arguments or no game info data available!"))
     },
     warning = function(w) {
     },
@@ -252,9 +249,9 @@ cfbd_game_info <- function(year,
 #' @param week (*Integer* optional): Week - values from 1-15, 1-14 for seasons pre-playoff (i.e. 2013 or earlier)
 #' @param season_type (*String* default regular): Select Season Type: regular, postseason, or both
 #' @param team (*String* optional): D-I Team
-#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference\cr
-#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC\cr
-#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC\cr
+#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
+#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
+#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
 #'
 #' @return [cfbd_game_weather()] - A data frame with 23 variables:
 #' \describe{
@@ -335,18 +332,19 @@ cfbd_game_weather <- function(year,
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
-
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
@@ -354,8 +352,11 @@ cfbd_game_weather <- function(year,
         janitor::clean_names()
 
       df <- df %>%
-        dplyr::rename(game_id = .data$id) %>%
-        as.data.frame()
+        dplyr::rename(game_id = .data$id)
+
+
+      df <- df %>%
+        make_cfbfastR_data("Game weather data from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no game weather data available!"))
@@ -389,7 +390,7 @@ cfbd_game_weather <- function(year,
 #' @export
 #' @examples
 #' \donttest{
-#'   cfbd_calendar(2019)
+#'   try(cfbd_calendar(2019))
 #' }
 
 cfbd_calendar <- function(year) {
@@ -409,28 +410,32 @@ cfbd_calendar <- function(year) {
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
 
   df <- data.frame()
-
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON() %>%
-        janitor::clean_names() %>%
-        as.data.frame()
+        janitor::clean_names()
+
+
+      df <- df %>%
+        make_cfbfastR_data("Calendar data from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
-        message(glue::glue("{Sys.time()}:Invalid arguments or no calendar data available!"))
+      message(glue::glue("{Sys.time()}:Invalid arguments or no calendar data available!"))
     },
     warning = function(w) {
     },
@@ -446,9 +451,9 @@ cfbd_calendar <- function(year) {
 #' @param week (*Integer* optional): Week, values from 1-15, 1-14 for seasons pre-playoff (i.e. 2013 or earlier)
 #' @param season_type (*String* default both): Select Season Type, regular, postseason, or both
 #' @param team (*String* optional): D-I Team
-#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference\cr
-#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC\cr
-#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC\cr
+#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
+#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
+#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
 #' @param media_type (*String* optional): Media type filter: tv, radio, web, ppv, or mobile
 #'
 #' @return [cfbd_game_media()] - A data frame with 13 variables:
@@ -479,7 +484,7 @@ cfbd_calendar <- function(year) {
 #' @export
 #' @examples
 #' \donttest{
-#'   cfbd_game_media(2019, week = 4, conference = "ACC")
+#'   try(cfbd_game_media(2019, week = 4, conference = "ACC"))
 #' }
 cfbd_game_media <- function(year,
                             week = NULL,
@@ -529,14 +534,6 @@ cfbd_game_media <- function(year,
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
 
   cols <- c(
     "game_id", "season", "week", "season_type", "start_time",
@@ -547,6 +544,16 @@ cfbd_game_media <- function(year,
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
@@ -563,11 +570,14 @@ cfbd_game_media <- function(year,
       df <- df[!duplicated(df), ]
 
       df <- df %>%
-        dplyr::select(cols, tidyr::everything()) %>%
-        as.data.frame()
+        dplyr::select(cols, tidyr::everything())
+
+
+      df <- df %>%
+        make_cfbfastR_data("Game media data from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
-        message(glue::glue("{Sys.time()}: Invalid arguments or no game media data available!"))
+      message(glue::glue("{Sys.time()}: Invalid arguments or no game media data available!"))
     },
     warning = function(w) {
     },
@@ -669,7 +679,7 @@ cfbd_game_media <- function(year,
 #' @export
 #' @examples
 #' \donttest{
-#'  cfbd_game_box_advanced(game_id = 401114233)
+#'   try(cfbd_game_box_advanced(game_id = 401114233))
 #' }
 #'
 
@@ -689,24 +699,25 @@ cfbd_game_box_advanced <- function(game_id, long = FALSE) {
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
-
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content, tidyr::unnest, and return result as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON(flatten = TRUE) %>%
-        furrr::future_map_if(is.data.frame, list) %>%
-        furrr::future_map_if(is.data.frame, list)
+        purrr::map_if(is.data.frame, list) %>%
+        purrr::map_if(is.data.frame, list)
 
       df <- tibble::enframe(unlist(df$teams, use.names = TRUE))
       team1 <- seq(1, nrow(df) - 1, by = 2)
@@ -760,17 +771,20 @@ cfbd_game_box_advanced <- function(game_id, long = FALSE) {
           dplyr::select(-.data$name) %>%
           dplyr::mutate_all(as.numeric) %>%
           dplyr::bind_cols(team)  %>%
-          dplyr::select(.data$team, tidyr::everything()) %>%
-          as.data.frame()
+          dplyr::select(.data$team, tidyr::everything())
         df <- df %>%
           dplyr::rename(
             rushing_line_yds_avg = .data$rushing_line_yd_avg,
             rushing_second_lvl_yds_avg = .data$rushing_second_lvl_yd_avg,
             rushing_open_field_yds_avg = .data$rushing_open_field_yd_avg)
+
+        df <- df %>%
+          make_cfbfastR_data("Advanced box score data from CollegeFootballData.com",Sys.time())
+
       }
     },
     error = function(e) {
-        message(glue::glue("{Sys.time()}: game_id '{game_id}' invalid or no game advanced box score data available!"))
+      message(glue::glue("{Sys.time()}: game_id '{game_id}' invalid or no game advanced box score data available!"))
     },
     warning = function(w) {
     },
@@ -786,13 +800,13 @@ cfbd_game_box_advanced <- function(game_id, long = FALSE) {
 #' @param week (*Integer* optional): Week - values from 1-15, 1-14 for seasons pre-playoff (i.e. 2013 or earlier)
 #' @param season_type (*String* default regular): Select Season Type: regular or postseason
 #' @param team (*String* optional): D-I Team
-#' @param category (*String* optional): Category filter (e.g defensive)\cr
-#' Offense: passing, receiving, rushing\cr
-#' Defense: defensive, fumbles, interceptions\cr
-#' Special Teams: punting, puntReturns, kicking, kickReturns\cr
-#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference\cr
-#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC\cr
-#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC\cr
+#' @param category (*String* optional): Category filter (e.g defensive)
+#' Offense: passing, receiving, rushing
+#' Defense: defensive, fumbles, interceptions
+#' Special Teams: punting, puntReturns, kicking, kickReturns
+#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
+#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
+#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
 #' @param game_id (*Integer* optional): Game ID filter for querying a single game
 #' Can be found using the [cfbd_game_info()] function
 #'
@@ -844,9 +858,9 @@ cfbd_game_box_advanced <- function(game_id, long = FALSE) {
 #' @export
 #' @examples
 #' \donttest{
-#'   cfbd_game_player_stats(year = 2020, week = 15, team = "Alabama")
+#'   try(cfbd_game_player_stats(year = 2020, week = 15, team = "Alabama"))
 #'
-#'   cfbd_game_player_stats(2013, week = 1, team = "Florida State", category = "passing")
+#'   try(cfbd_game_player_stats(2013, week = 1, team = "Florida State", category = "passing"))
 #' }
 
 cfbd_game_player_stats <- function(year,
@@ -872,7 +886,7 @@ cfbd_game_player_stats <- function(year,
   }
   if (!is.null(week) && !is.numeric(week) && nchar(week) > 2) {
     # Check if week is numeric, if not NULL
-      cli::cli_abort("Enter valid week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
+    cli::cli_abort("Enter valid week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
   }
 
   if (!(season_type %in% c("postseason", "both","regular"))) {
@@ -921,16 +935,6 @@ cfbd_game_player_stats <- function(year,
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-
-  # Check the result
-  check_status(res)
-
   cols <- c(
     "game_id", "team", "conference", "home_away", "points", "category",
     "athlete_id", "name", "c_att", "yds", "avg", "td", "int", "qbr",
@@ -946,22 +950,32 @@ cfbd_game_player_stats <- function(year,
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content, tidyr::unnest, and return result as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON(flatten = TRUE) %>%
-        furrr::future_map_if(is.data.frame, list) %>%
+        purrr::map_if(is.data.frame, list) %>%
         dplyr::as_tibble() %>%
         dplyr::rename(game_id = .data$id) %>%
         tidyr::unnest(.data$teams) %>%
-        furrr::future_map_if(is.data.frame, list) %>%
+        purrr::map_if(is.data.frame, list) %>%
         dplyr::as_tibble() %>%
         tidyr::unnest(.data$categories) %>%
-        furrr::future_map_if(is.data.frame, list) %>%
+        purrr::map_if(is.data.frame, list) %>%
         dplyr::as_tibble() %>%
         dplyr::rename(category = .data$name) %>%
         tidyr::unnest(.data$types) %>%
-        furrr::future_map_if(is.data.frame, list) %>%
+        purrr::map_if(is.data.frame, list) %>%
         dplyr::as_tibble() %>%
         dplyr::rename(stat_category = .data$name) %>%
         tidyr::unnest(.data$athletes) %>%
@@ -977,9 +991,13 @@ cfbd_game_player_stats <- function(year,
 
       df <- df %>%
         dplyr::select(cols, dplyr::everything())
+
+
+      df <- df %>%
+        make_cfbfastR_data("Game player stats data from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
-        message(glue::glue("{Sys.time()}: Invalid arguments or no game player stats data available!"))
+      message(glue::glue("{Sys.time()}: Invalid arguments or no game player stats data available!"))
     },
     warning = function(w) {
     },
@@ -1001,8 +1019,8 @@ cfbd_game_player_stats <- function(year,
 #' **Get team records by year**
 #' @param year (*Integer* optional): Year, 4 digit format (*YYYY*)
 #' @param team (*String* optional): Team - Select a valid team, D1 football
-#' @param conference (*String* optional): DI Conference abbreviation - Select a valid FBS conference\cr
-#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC\cr
+#' @param conference (*String* optional): DI Conference abbreviation - Select a valid FBS conference
+#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
 #' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
 #' @return [cfbd_game_records()] - A data frame with 21 variables:
 #' \describe{
@@ -1038,9 +1056,9 @@ cfbd_game_player_stats <- function(year,
 #' @export
 #' @examples
 #' \donttest{
-#'   cfbd_game_records(2018, team = "Notre Dame")
+#'   try(cfbd_game_records(2018, team = "Notre Dame"))
 #'
-#'   cfbd_game_records(2013, team = "Florida State")
+#'   try(cfbd_game_records(2013, team = "Florida State"))
 #' }
 
 cfbd_game_records <- function(year,
@@ -1078,19 +1096,19 @@ cfbd_game_records <- function(year,
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-
-  # Check the result
-  check_status(res)
-
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
+      )
+
+      # Check the result
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
@@ -1114,9 +1132,12 @@ cfbd_game_records <- function(year,
           away_losses = .data$awayGames.losses,
           away_ties = .data$awayGames.ties
         )
+
+      df <- df %>%
+        make_cfbfastR_data("Game records data from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
-        message(glue::glue("{Sys.time()}: Invalid arguments or no game records data available!"))
+      message(glue::glue("{Sys.time()}: Invalid arguments or no game records data available!"))
     },
     warning = function(w) {
     },
@@ -1134,10 +1155,10 @@ cfbd_game_records <- function(year,
 #' @param week (*Integer* optional): Week - values range from 1-15, 1-14 for seasons pre-playoff, i.e. 2013 or earlier
 #' @param season_type (*String* default: regular): Select Season Type - regular, postseason, or both
 #' @param team (*String* optional): D-I Team
-#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference\cr
-#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC\cr
-#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC\cr
-#' @param game_id (*Integer* optional): Game ID filter for querying a single game\cr
+#' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
+#' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
+#' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
+#' @param game_id (*Integer* optional): Game ID filter for querying a single game
 #' Can be found using the [cfbd_game_info()] function
 #' @param rows_per_team (*Integer* default 1): Both Teams for each game on one or two row(s), Options: 1 or 2
 #'
@@ -1147,6 +1168,8 @@ cfbd_game_records <- function(year,
 #'   \item{`school`: character.}{Team name.}
 #'   \item{`conference`: character.}{Conference of the team.}
 #'   \item{`home_away`: character.}{Home/Away Flag.}
+#'   \item{`opponent`: character.}{Opponent team name.}
+#'   \item{`opponent_conference`: character.}{Conference of the opponent team.}
 #'   \item{`points`: integer.}{Team points.}
 #'   \item{`total_yards`: character.}{Team total yards.}
 #'   \item{`net_passing_yards`: character.}{Team net passing yards.}
@@ -1183,8 +1206,6 @@ cfbd_game_records <- function(year,
 #'   \item{`defensive_tds`: character.}{Team defensive touchdowns.}
 #'   \item{`total_penalties_yards`: character.}{Team total penalty yards.}
 #'   \item{`possession_time`: character.}{Team time of possession.}
-#'   \item{`conference_allowed`: character.}{Conference of the opponent team.}
-#'   \item{`home_away_allowed`: character.}{Flag for if the opponent was the home or away team.}
 #'   \item{`points_allowed`: integer.}{Points for the opponent.}
 #'   \item{`total_yards_allowed`: character.}{Opponent total yards.}
 #'   \item{`net_passing_yards_allowed`: character.}{Opponent net passing yards.}
@@ -1222,6 +1243,7 @@ cfbd_game_records <- function(year,
 #'   \item{`total_penalties_yards_allowed`: character.}{Opponent total penalty yards.}
 #'   \item{`possession_time_allowed`: character.}{Opponent time of possession.}
 #' }
+#'
 #' @keywords Team Game Stats
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET RETRY
@@ -1235,9 +1257,9 @@ cfbd_game_records <- function(year,
 #' @export
 #' @examples
 #' \donttest{
-#'   cfbd_game_team_stats(2019, team = "LSU")
+#'   try(cfbd_game_team_stats(2019, team = "LSU"))
 #'
-#'   cfbd_game_team_stats(2013, team = "Florida State")
+#'   try(cfbd_game_team_stats(2013, team = "Florida State"))
 #' }
 
 cfbd_game_team_stats <- function(year,
@@ -1298,165 +1320,185 @@ cfbd_game_team_stats <- function(year,
   # Check for CFBD API key
   if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
 
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
+  df <- data.frame()
+  tryCatch(
+    expr = {
 
-  # Check the result
-  check_status(res)
-
-
-  cols <- c(
-    "id", "school", "conference", "home_away",
-    "points", "rushing_t_ds", "punt_return_yards", "punt_return_t_ds",
-    "punt_returns", "passing_t_ds", "kicking_points",
-    "interception_yards", "interception_t_ds", "passes_intercepted",
-    "fumbles_recovered", "total_fumbles", "tackles_for_loss",
-    "defensive_t_ds", "tackles", "sacks", "qb_hurries",
-    "passes_deflected", "possession_time", "interceptions",
-    "fumbles_lost", "turnovers", "total_penalties_yards",
-    "yards_per_rush_attempt", "rushing_attempts", "rushing_yards",
-    "yards_per_pass", "completion_attempts", "net_passing_yards",
-    "total_yards", "fourth_down_eff", "third_down_eff",
-    "first_downs", "kick_return_yards", "kick_return_t_ds",
-    "kick_returns"
-  )
-  # Get the content, unnest, and return result as data.frame
-  df <- res %>%
-    httr::content(as = "text", encoding = "UTF-8") %>%
-    jsonlite::fromJSON(flatten = TRUE) %>%
-    furrr::future_map_if(is.data.frame, list) %>%
-    dplyr::as_tibble()
-
-  if (nrow(df) == 0) {
-      warning("Most likely a bye week, the data pulled from the API was empty. Returning nothing
-              for this one week or team.")
-    return(NULL)
-  }
-  df <- df %>%
-    tidyr::unnest(.data$teams) %>%
-    tidyr::unnest(.data$stats)
-
-  # Pivot category columns to get stats for each team game on one row
-  df <- tidyr::pivot_wider(df,
-    names_from = .data$category,
-    values_from = .data$stat
-  )
-  df <- df %>%
-    janitor::clean_names()
-  df[cols[!(cols %in% colnames(df))]] <- NA
-  df <- df %>%
-    dplyr::rename(
-      game_id = .data$id,
-      rush_tds = .data$rushing_t_ds,
-      punt_return_tds = .data$punt_return_t_ds,
-      passing_tds = .data$passing_t_ds,
-      interception_tds = .data$interception_t_ds,
-      defensive_tds = .data$defensive_t_ds,
-      kick_return_tds = .data$kick_return_t_ds
-    )
-
-  if (rows_per_team == 1) {
-    # Join pivoted data with itself to get ultra-wide row
-    # containing all game stats on one row for both teams
-    df <- df %>%
-      dplyr::left_join(df,
-        by = c("game_id", "school"),
-        suffix = c("", "_allowed")
+      # Create the GET request and set response as res
+      res <- httr::RETRY(
+        "GET", full_url,
+        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
       )
 
-    cols1 <- c(
-      "game_id", "school", "conference", "home_away",
-      "points", "total_yards", "net_passing_yards",
-      "completion_attempts", "passing_tds", "yards_per_pass",
-      "passes_intercepted", "interception_yards", "interception_tds",
-      "rushing_attempts", "rushing_yards", "rush_tds", "yards_per_rush_attempt",
-      "first_downs", "third_down_eff", "fourth_down_eff",
-      "punt_returns", "punt_return_yards", "punt_return_tds",
-      "kick_return_yards", "kick_return_tds", "kick_returns", "kicking_points",
-      "fumbles_recovered", "fumbles_lost", "total_fumbles",
-      "tackles", "tackles_for_loss", "sacks", "qb_hurries",
-      "interceptions", "passes_deflected", "turnovers", "defensive_tds",
-      "total_penalties_yards", "possession_time",
-      "conference_allowed", "home_away_allowed",
-      "points_allowed", "total_yards_allowed", "net_passing_yards_allowed",
-      "completion_attempts_allowed", "passing_tds_allowed", "yards_per_pass_allowed",
-      "passes_intercepted_allowed", "interception_yards_allowed", "interception_tds_allowed",
-      "rushing_attempts_allowed", "rushing_yards_allowed", "rush_tds_allowed", "yards_per_rush_attempt_allowed",
-      "first_downs_allowed", "third_down_eff_allowed", "fourth_down_eff_allowed",
-      "punt_returns_allowed", "punt_return_yards_allowed", "punt_return_tds_allowed",
-      "kick_return_yards_allowed", "kick_return_tds_allowed", "kick_returns_allowed", "kicking_points_allowed",
-      "fumbles_recovered_allowed", "fumbles_lost_allowed", "total_fumbles_allowed",
-      "tackles_allowed", "tackles_for_loss_allowed", "sacks_allowed", "qb_hurries_allowed",
-      "interceptions_allowed", "passes_deflected_allowed", "turnovers_allowed", "defensive_tds_allowed",
-      "total_penalties_yards_allowed", "possession_time_allowed"
-    )
+      # Check the result
+      check_status(res)
+
+
+      cols <- c(
+        "id", "school", "conference", "home_away",
+        "points", "rushing_t_ds", "punt_return_yards", "punt_return_t_ds",
+        "punt_returns", "passing_t_ds", "kicking_points",
+        "interception_yards", "interception_t_ds", "passes_intercepted",
+        "fumbles_recovered", "total_fumbles", "tackles_for_loss",
+        "defensive_t_ds", "tackles", "sacks", "qb_hurries",
+        "passes_deflected", "possession_time", "interceptions",
+        "fumbles_lost", "turnovers", "total_penalties_yards",
+        "yards_per_rush_attempt", "rushing_attempts", "rushing_yards",
+        "yards_per_pass", "completion_attempts", "net_passing_yards",
+        "total_yards", "fourth_down_eff", "third_down_eff",
+        "first_downs", "kick_return_yards", "kick_return_t_ds",
+        "kick_returns"
+      )
+      # Get the content, unnest, and return result as data.frame
+      df <- res %>%
+        httr::content(as = "text", encoding = "UTF-8") %>%
+        jsonlite::fromJSON(flatten = TRUE) %>%
+        purrr::map_if(is.data.frame, list) %>%
+        dplyr::as_tibble()
+
+      if (nrow(df) == 0) {
+        warning("Most likely a bye week, the data pulled from the API was empty. Returning nothing
+              for this one week or team.")
+        return(NULL)
+      }
+      df <- df %>%
+        tidyr::unnest(.data$teams) %>%
+        tidyr::unnest(.data$stats)
+
+      # Pivot category columns to get stats for each team game on one row
+      df <- tidyr::pivot_wider(df,
+                               names_from = .data$category,
+                               values_from = .data$stat
+      )
+      df <- df %>%
+        janitor::clean_names()
+      df[cols[!(cols %in% colnames(df))]] <- NA
+      df <- df %>%
+        dplyr::rename(
+          game_id = .data$id,
+          rush_tds = .data$rushing_t_ds,
+          punt_return_tds = .data$punt_return_t_ds,
+          passing_tds = .data$passing_t_ds,
+          interception_tds = .data$interception_t_ds,
+          defensive_tds = .data$defensive_t_ds,
+          kick_return_tds = .data$kick_return_t_ds
+        )
+
+      if (rows_per_team == 1) {
+        # Join pivoted data with itself to get ultra-wide row
+        # containing all game stats on one row for both teams
+        df <- df %>%
+          dplyr::mutate(opponent_home_away = ifelse(.data$home_away == "home","away","home")) %>%
+          dplyr::left_join(df,
+                           by = c("game_id", "opponent_home_away" = "home_away"),
+                           suffix = c("", "_allowed")
+          ) %>%
+          dplyr::rename(opponent = .data$school_allowed,
+                        opponent_conference = .data$conference_allowed)
+
+        cols1 <- c(
+          "game_id", "school", "conference", "home_away","opponent","opponent_conference",
+          "points", "total_yards", "net_passing_yards",
+          "completion_attempts", "passing_tds", "yards_per_pass",
+          "passes_intercepted", "interception_yards", "interception_tds",
+          "rushing_attempts", "rushing_yards", "rush_tds", "yards_per_rush_attempt",
+          "first_downs", "third_down_eff", "fourth_down_eff",
+          "punt_returns", "punt_return_yards", "punt_return_tds",
+          "kick_return_yards", "kick_return_tds", "kick_returns", "kicking_points",
+          "fumbles_recovered", "fumbles_lost", "total_fumbles",
+          "tackles", "tackles_for_loss", "sacks", "qb_hurries",
+          "interceptions", "passes_deflected", "turnovers", "defensive_tds",
+          "total_penalties_yards", "possession_time",
+          "points_allowed", "total_yards_allowed", "net_passing_yards_allowed",
+          "completion_attempts_allowed", "passing_tds_allowed", "yards_per_pass_allowed",
+          "passes_intercepted_allowed", "interception_yards_allowed", "interception_tds_allowed",
+          "rushing_attempts_allowed", "rushing_yards_allowed", "rush_tds_allowed", "yards_per_rush_attempt_allowed",
+          "first_downs_allowed", "third_down_eff_allowed", "fourth_down_eff_allowed",
+          "punt_returns_allowed", "punt_return_yards_allowed", "punt_return_tds_allowed",
+          "kick_return_yards_allowed", "kick_return_tds_allowed", "kick_returns_allowed", "kicking_points_allowed",
+          "fumbles_recovered_allowed", "fumbles_lost_allowed", "total_fumbles_allowed",
+          "tackles_allowed", "tackles_for_loss_allowed", "sacks_allowed", "qb_hurries_allowed",
+          "interceptions_allowed", "passes_deflected_allowed", "turnovers_allowed", "defensive_tds_allowed",
+          "total_penalties_yards_allowed", "possession_time_allowed"
+        )
+
+        if (!is.null(team)) {
+          team <- URLdecode(team)
+
+          df <- df %>%
+            dplyr::filter(.data$school == team) %>%
+            dplyr::select(cols1)
+
+
+        } else if (!is.null(conference)) {
+          confs <- cfbd_conferences()
+
+          conference <- URLdecode(conference)
+
+          conf_name <- confs[confs$abbreviation == conference, ]$name
+
+          df <- df %>%
+            dplyr::filter(conference == conf_name) %>%
+            dplyr::select(cols1)
+
+
+        } else {
+          df <- df %>%
+            dplyr::select(cols1)
+
+        }
+      } else {
+        cols2 <- c(
+          "game_id", "school", "conference", "home_away",
+          "points", "total_yards", "net_passing_yards",
+          "completion_attempts", "passing_tds", "yards_per_pass",
+          "passes_intercepted", "interception_yards", "interception_tds",
+          "rushing_attempts", "rushing_yards", "rush_tds", "yards_per_rush_attempt",
+          "first_downs", "third_down_eff", "fourth_down_eff",
+          "punt_returns", "punt_return_yards", "punt_return_tds",
+          "kick_return_yards", "kick_return_tds", "kick_returns", "kicking_points",
+          "fumbles_recovered", "fumbles_lost", "total_fumbles",
+          "tackles", "tackles_for_loss", "sacks", "qb_hurries",
+          "interceptions", "passes_deflected", "turnovers", "defensive_tds",
+          "total_penalties_yards", "possession_time"
+        )
+        if (!is.null(team)) {
+          team <- URLdecode(team <- team)
+
+          df <- df %>%
+            dplyr::filter(.data$school == team) %>%
+            dplyr::select(cols2)
+
+        } else if (!is.null(conference)) {
+          confs <- cfbd_conferences()
+
+          conference <- URLdecode(conference)
+
+          conf_name <- confs[confs$abbreviation == conference, ]$name
+
+          df <- df %>%
+            dplyr::filter(conference == conf_name) %>%
+            dplyr::select(cols2)
+
+
+        } else {
+          df <- df %>%
+            dplyr::select(cols2)
+
+        }
+      }
 
-    if (!is.null(team)) {
-      team <- URLdecode(team)
 
       df <- df %>%
-        dplyr::filter(.data$school == team) %>%
-        dplyr::select(cols1)
-
-      return(df)
-    } else if (!is.null(conference)) {
-      confs <- cfbd_conferences()
-
-      conference <- URLdecode(conference)
-
-      conf_name <- confs[confs$abbreviation == conference, ]$name
-
-      df <- df %>%
-        dplyr::filter(conference == conf_name) %>%
-        dplyr::select(cols1)
-
-      return(df)
-    } else {
-      df <- df %>%
-        dplyr::select(cols1)
-      return(df)
+        make_cfbfastR_data("Team stats data from CollegeFootballData.com",Sys.time())
+    },
+    error = function(e) {
+      message(glue::glue("{Sys.time()}: Invalid arguments or no team stats data available!"))
+    },
+    warning = function(w) {
+    },
+    finally = {
     }
-  } else {
-    cols2 <- c(
-      "game_id", "school", "conference", "home_away",
-      "points", "total_yards", "net_passing_yards",
-      "completion_attempts", "passing_tds", "yards_per_pass",
-      "passes_intercepted", "interception_yards", "interception_tds",
-      "rushing_attempts", "rushing_yards", "rush_tds", "yards_per_rush_attempt",
-      "first_downs", "third_down_eff", "fourth_down_eff",
-      "punt_returns", "punt_return_yards", "punt_return_tds",
-      "kick_return_yards", "kick_return_tds", "kick_returns", "kicking_points",
-      "fumbles_recovered", "fumbles_lost", "total_fumbles",
-      "tackles", "tackles_for_loss", "sacks", "qb_hurries",
-      "interceptions", "passes_deflected", "turnovers", "defensive_tds",
-      "total_penalties_yards", "possession_time"
-    )
-    if (!is.null(team)) {
-      team <- URLdecode(team <- team)
-
-      df <- df %>%
-        dplyr::filter(.data$school == team) %>%
-        dplyr::select(cols2)
-      return(df)
-    } else if (!is.null(conference)) {
-      confs <- cfbd_conferences()
-
-      conference <- URLdecode(conference)
-
-      conf_name <- confs[confs$abbreviation == conference, ]$name
-
-      df <- df %>%
-        dplyr::filter(conference == conf_name) %>%
-        dplyr::select(cols2)
-
-      return(df)
-    } else {
-      df <- df %>%
-        dplyr::select(cols2)
-      return(df)
-    }
-  }
+  )
+  return(df)
 }
