@@ -9,7 +9,7 @@
 load_ep_model <- function(){
   ep_model <- NULL
   # load the model from GitHub because it is too large for the package
-  .url = url("https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/models/ep_model.Rdata")
+  .url = url("https://raw.githubusercontent.com/sportsdataverse/cfbfastR-data/main/models/ep_model.Rdata")
   on.exit(close(.url))
   try(
     load(.url),
@@ -19,7 +19,7 @@ load_ep_model <- function(){
 }
 load_fg_model <- function(){
   fg_model <- NULL
-  .url = url("https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/models/fg_model.Rdata")
+  .url = url("https://raw.githubusercontent.com/sportsdataverse/cfbfastR-data/main/models/fg_model.Rdata")
   on.exit(close(.url))
   try(
     load(.url),
@@ -29,7 +29,7 @@ load_fg_model <- function(){
 }
 load_wp_model <- function(){
   wp_model <- NULL
-  .url = url("https://raw.githubusercontent.com/saiemgilani/cfbfastR-data/master/models/wp_model.Rdata")
+  .url = url("https://raw.githubusercontent.com/sportsdataverse/cfbfastR-data/main/models/wp_model.Rdata")
   on.exit(close(.url))
   try(
     load(.url),
@@ -38,14 +38,3 @@ load_wp_model <- function(){
   return (wp_model)
 }
 
-
-#' load function from package
-#' @param pkg package
-#' @param fun function
-#' @return function
-#' @keywords internal
-get_fun_from_pkg <- function(pkg, fun) {
-  require(pkg, character.only = TRUE)
-  eval(parse(text = fun))
-}
-
